#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LDIVIDE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LDIVIDE_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/ldivide.hpp>

#endif
